#include <QtGui>
#include <QPushButton>
#include <QMainWindow>

class MainWidget : public QMainWindow 
{
Q_OBJECT
public:
	MainWidget(QWidget *parent = 0);

public slots:
	void AddAlarm();
        void DelAlarm( const QModelIndex & index );
        void DelAlarm();
        void refreshList();
        void contextMenu(const QPoint & pt);

private:
        QListView *m_view;
};


